@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# 2011 Steven Armstrong (steven-cdist at armstrong.cc)
+# 2011-2017 Steven Armstrong (steven-cdist at armstrong.cc)
 # 2011-2015 Nico Schottelius (nico-cdist at schottelius.org)
 # 2014 Daniel Heule (hda at sfs.biz)
 #
@@ -21,17 +21,12 @@
 #
 #
 
-import fnmatch
-import logging
 import os
-import collections
 
 import cdist
 import cdist.core
 from cdist.util import fsproperty
 
-log = logging.getLogger(__name__)
-
 
 class IllegalObjectIdError(cdist.Error):
     def __init__(self, object_id, message=None):
@@ -85,6 +80,8 @@ class CdistObject(object):
         self.code_local_path = os.path.join(self.path, "code-local")
         self.code_remote_path = os.path.join(self.path, "code-remote")
         self.parameter_path = os.path.join(self.path, "parameter")
+        self.stdout_path = os.path.join(self.absolute_path, "stdout")
+        self.stderr_path = os.path.join(self.absolute_path, "stderr")
 
     @classmethod
     def list_objects(cls, object_base_path, type_base_path, object_marker):
@@ -107,7 +104,7 @@ class CdistObject(object):
     @classmethod
     def list_type_names(cls, object_base_path):
         """Return a list of type names"""
-        return os.listdir(object_base_path)
+        return cdist.core.listdir(object_base_path)
 
     @staticmethod
     def split_name(object_name):
@@ -145,9 +142,13 @@ class CdistObject(object):
             if '//' in self.object_id:
                 raise IllegalObjectIdError(
                         self.object_id, 'object_id may not contain //')
-            if self.object_id == '.':
-                raise IllegalObjectIdError(
-                        self.object_id, 'object_id may not be a .')
+
+            _invalid_object_ids = ('.', '/', )
+            for ioid in _invalid_object_ids:
+                if self.object_id == ioid:
+                    raise IllegalObjectIdError(
+                        self.object_id,
+                        'object_id may not be a {}'.format(ioid))
 
         # If no object_id and type is not singleton => error out
         if not self.object_id and not self.cdist_type.is_singleton:
@@ -247,10 +248,11 @@ class CdistObject(object):
         """Create this cdist object on the filesystem.
         """
         try:
-            os.makedirs(self.absolute_path, exist_ok=allow_overwrite)
-            absolute_parameter_path = os.path.join(self.base_path,
-                                                   self.parameter_path)
-            os.makedirs(absolute_parameter_path, exist_ok=allow_overwrite)
+            for path in (self.absolute_path,
+                         os.path.join(self.base_path, self.parameter_path),
+                         self.stdout_path,
+                         self.stderr_path):
+                os.makedirs(path, exist_ok=allow_overwrite)
         except EnvironmentError as error:
             raise cdist.Error(('Error creating directories for cdist object: '
                                '%s: %s') % (self, error))
