@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# 2011 Steven Armstrong (steven-cdist at armstrong.cc)
+# 2011-2017 Steven Armstrong (steven-cdist at armstrong.cc)
 # 2011-2013 Nico Schottelius (nico-cdist at schottelius.org)
 # 2014 Daniel Heule (hda at sfs.biz)
 #
@@ -21,12 +21,8 @@
 #
 #
 
-import logging
 import os
-
-import cdist
-
-log = logging.getLogger(__name__)
+from . import util
 
 
 '''
@@ -59,6 +55,7 @@ gencode-local
         __object_fq: full qualified object id, iow: $type.name + / + object_id
         __type: full qualified path to the type's dir
         __files: full qualified path to the files dir
+        __target_host_tags: comma spearated list of host tags
 
     returns: string containing the generated code or None
 
@@ -77,6 +74,7 @@ gencode-remote
         __object_fq: full qualified object id, iow: $type.name + / + object_id
         __type: full qualified path to the type's dir
         __files: full qualified path to the files dir
+        __target_host_tags: comma spearated list of host tags
 
     returns: string containing the generated code or None
 
@@ -109,6 +107,10 @@ class Code(object):
             '__target_fqdn': self.target_host[2],
             '__global': self.local.base_path,
             '__files': self.local.files_path,
+            '__target_host_tags': self.local.target_host_tags,
+            '__cdist_log_level': util.log_level_env_var_val(local.log),
+            '__cdist_log_level_name': util.log_level_name_env_var_val(
+                local.log),
         }
 
     def _run_gencode(self, cdist_object, which):
@@ -125,8 +127,18 @@ class Code(object):
                 '__object_name': cdist_object.name,
             })
             message_prefix = cdist_object.name
-            return self.local.run_script(script, env=env, return_output=True,
-                                         message_prefix=message_prefix)
+            if self.local.save_output_streams:
+                stderr_path = os.path.join(cdist_object.stderr_path,
+                                           'gencode-' + which)
+                with open(stderr_path, 'ba+') as stderr:
+                    return self.local.run_script(script, env=env,
+                                                 return_output=True,
+                                                 message_prefix=message_prefix,
+                                                 stderr=stderr)
+            else:
+                return self.local.run_script(script, env=env,
+                                             return_output=True,
+                                             message_prefix=message_prefix)
 
     def run_gencode_local(self, cdist_object):
         """Run the gencode-local script for the given cdist object."""
@@ -143,15 +155,24 @@ class Code(object):
                               cdist_object.code_remote_path)
         destination = os.path.join(self.remote.object_path,
                                    cdist_object.code_remote_path)
-        # FIXME: BUG: do not create destination, but top level of destination!
-        self.remote.mkdir(destination)
+        self.remote.mkdir(os.path.dirname(destination))
         self.remote.transfer(source, destination)
 
     def _run_code(self, cdist_object, which, env=None):
         which_exec = getattr(self, which)
         script = os.path.join(which_exec.object_path,
                               getattr(cdist_object, 'code_%s_path' % which))
-        return which_exec.run_script(script, env=env)
+        if which_exec.save_output_streams:
+            stderr_path = os.path.join(cdist_object.stderr_path,
+                                       'code-' + which)
+            stdout_path = os.path.join(cdist_object.stdout_path,
+                                       'code-' + which)
+            with open(stderr_path, 'ba+') as stderr, \
+                    open(stdout_path, 'ba+') as stdout:
+                return which_exec.run_script(script, env=env, stdout=stdout,
+                                             stderr=stderr)
+        else:
+            return which_exec.run_script(script, env=env)
 
     def run_code_local(self, cdist_object):
         """Run the code-local script for the given cdist object."""
