@@ -28,6 +28,7 @@ import sys
 
 import cdist
 from cdist import core
+from cdist import flock
 
 
 class MissingRequiredEnvironmentVariableError(cdist.Error):
@@ -94,20 +95,33 @@ class Emulator(object):
         """Emulate type commands (i.e. __file and co)"""
 
         self.commandline()
-        self.setup_object()
-        self.save_stdin()
-        self.record_requirements()
-        self.record_auto_requirements()
-        self.log.debug("Finished %s %s" % (
-            self.cdist_object.path, self.parameters))
+        self.init_object()
+
+        # locking for parallel execution
+        with flock.Flock(self.flock_path):
+            self.setup_object()
+            self.save_stdin()
+            self.record_requirements()
+            self.record_auto_requirements()
+            self.log.trace("Finished %s %s" % (
+                self.cdist_object.path, self.parameters))
 
     def __init_log(self):
         """Setup logging facility"""
 
-        if '__cdist_debug' in self.env:
-            logging.root.setLevel(logging.DEBUG)
+        if '__cdist_log_level' in self.env:
+            try:
+                loglevel = self.env['__cdist_log_level']
+                level = int(loglevel)
+            except ValueError:
+                level = logging.WARNING
         else:
-            logging.root.setLevel(logging.INFO)
+            level = logging.WARNING
+        try:
+            logging.root.setLevel(level)
+        except (ValueError, TypeError):
+            # if invalid __cdist_log_level value
+            logging.root.setLevel(logging.WARNING)
 
         self.log = logging.getLogger(self.target_host[0])
 
@@ -148,10 +162,10 @@ class Emulator(object):
 
         # And finally parse/verify parameter
         self.args = parser.parse_args(self.argv[1:])
-        self.log.debug('Args: %s' % self.args)
+        self.log.trace('Args: %s' % self.args)
 
-    def setup_object(self):
-        # Setup object - and ensure it is not in args
+    def init_object(self):
+        # Initialize object - and ensure it is not in args
         if self.cdist_type.is_singleton:
             self.object_id = ''
         else:
@@ -162,7 +176,13 @@ class Emulator(object):
         self.cdist_object = core.CdistObject(
                 self.cdist_type, self.object_base_path, self.object_marker,
                 self.object_id)
+        lockfname = ('.' + self.cdist_type.name +
+                     self.object_id + '_' +
+                     self.object_marker + '.lock')
+        lockfname = lockfname.replace(os.sep, '_')
+        self.flock_path = os.path.join(self.object_base_path, lockfname)
 
+    def setup_object(self):
         # Create object with given parameters
         self.parameters = {}
         for key, value in vars(self.args).items():
@@ -181,7 +201,6 @@ class Emulator(object):
                               self.cdist_object.parameters,
                               self.object_source,
                               self.parameters))
-                self.log.error(errmsg)
                 raise cdist.Error(errmsg)
         else:
             if self.cdist_object.exists:
@@ -227,7 +246,7 @@ class Emulator(object):
         # Raises an error, if object cannot be created
         try:
             cdist_object = self.cdist_object.object_from_name(requirement)
-        except core.cdist_type.NoSuchTypeError as e:
+        except core.cdist_type.InvalidTypeError as e:
             self.log.error(("%s requires object %s, but type %s does not"
                             " exist. Defined at %s" % (
                                 self.cdist_object.name,
@@ -256,10 +275,10 @@ class Emulator(object):
         # (this would leed to an circular dependency)
         if ("CDIST_ORDER_DEPENDENCY" in self.env and
                 'CDIST_OVERRIDE' not in self.env):
-            # load object name created bevor this one from typeorder file ...
+            # load object name created befor this one from typeorder file ...
             with open(self.typeorder_path, 'r') as typecreationfile:
                 typecreationorder = typecreationfile.readlines()
-                # get the type created bevore this one ...
+                # get the type created before this one ...
                 try:
                     lastcreatedtype = typecreationorder[-2].strip()
                     if 'require' in self.env:
