@@ -27,6 +27,7 @@ import shutil
 import string
 import filecmp
 import random
+import logging
 
 import cdist
 from cdist import test
@@ -53,6 +54,7 @@ class EmulatorTestCase(test.CdistTestCase):
 
         self.local = local.Local(
             target_host=self.target_host,
+            target_host_tags=self.target_host_tags,
             base_root_path=host_base_path,
             host_dir_name=hostdir,
             exec_path=test.cdist_exec_path,
@@ -62,6 +64,8 @@ class EmulatorTestCase(test.CdistTestCase):
         self.manifest = core.Manifest(self.target_host, self.local)
         self.env = self.manifest.env_initial_manifest(self.script)
         self.env['__cdist_object_marker'] = self.local.object_marker_name
+        if '__cdist_log_level' in self.env:
+            del self.env['__cdist_log_level']
 
     def tearDown(self):
         shutil.rmtree(self.temp_dir)
@@ -72,14 +76,14 @@ class EmulatorTestCase(test.CdistTestCase):
 
     def test_nonexistent_type_exec(self):
         argv = ['__does-not-exist']
-        self.assertRaises(core.cdist_type.NoSuchTypeError, emulator.Emulator,
+        self.assertRaises(core.cdist_type.InvalidTypeError, emulator.Emulator,
                           argv, env=self.env)
 
     def test_nonexistent_type_requirement(self):
         argv = ['__file', '/tmp/foobar']
         self.env['require'] = '__does-not-exist/some-id'
         emu = emulator.Emulator(argv, env=self.env)
-        self.assertRaises(core.cdist_type.NoSuchTypeError, emu.run)
+        self.assertRaises(core.cdist_type.InvalidTypeError, emu.run)
 
     def test_illegal_object_id_requirement(self):
         argv = ['__file', '/tmp/foobar']
@@ -114,6 +118,31 @@ class EmulatorTestCase(test.CdistTestCase):
         emu = emulator.Emulator(argv, env=self.env)
         # if we get here all is fine
 
+    def test_loglevel(self):
+        argv = ['__file', '/tmp/foobar']
+        self.env['require'] = '__file/etc/*'
+        emu = emulator.Emulator(argv, env=self.env)
+        emu_loglevel = emu.log.getEffectiveLevel()
+        self.assertEqual(emu_loglevel, logging.WARNING)
+        self.env['__cdist_log_level'] = str(logging.DEBUG)
+        emu = emulator.Emulator(argv, env=self.env)
+        emu_loglevel = emu.log.getEffectiveLevel()
+        self.assertEqual(emu_loglevel, logging.DEBUG)
+        del self.env['__cdist_log_level']
+
+    def test_invalid_loglevel_value(self):
+        argv = ['__file', '/tmp/foobar']
+        self.env['require'] = '__file/etc/*'
+        emu = emulator.Emulator(argv, env=self.env)
+        emu_loglevel = emu.log.getEffectiveLevel()
+        self.assertEqual(emu_loglevel, logging.WARNING)
+        # lowercase is invalid
+        self.env['__cdist_log_level'] = 'debug'
+        emu = emulator.Emulator(argv, env=self.env)
+        emu_loglevel = emu.log.getEffectiveLevel()
+        self.assertEqual(emu_loglevel, logging.WARNING)
+        del self.env['__cdist_log_level']
+
     def test_requirement_via_order_dependency(self):
         self.env['CDIST_ORDER_DEPENDENCY'] = 'on'
         argv = ['__planet', 'erde']
@@ -156,6 +185,7 @@ class EmulatorConflictingRequirementsTestCase(test.CdistTestCase):
 
         self.local = local.Local(
             target_host=self.target_host,
+            target_host_tags=self.target_host_tags,
             base_root_path=host_base_path,
             host_dir_name=hostdir,
             exec_path=test.cdist_exec_path,
@@ -246,6 +276,7 @@ class AutoRequireEmulatorTestCase(test.CdistTestCase):
 
         self.local = local.Local(
             target_host=self.target_host,
+            target_host_tags=self.target_host_tags,
             base_root_path=host_base_path,
             host_dir_name=hostdir,
             exec_path=test.cdist_exec_path,
@@ -279,6 +310,7 @@ class OverrideTestCase(test.CdistTestCase):
 
         self.local = local.Local(
             target_host=self.target_host,
+            target_host_tags=self.target_host_tags,
             base_root_path=host_base_path,
             host_dir_name=hostdir,
             exec_path=test.cdist_exec_path,
@@ -322,6 +354,7 @@ class ArgumentsTestCase(test.CdistTestCase):
 
         self.local = local.Local(
             target_host=self.target_host,
+            target_host_tags=self.target_host_tags,
             base_root_path=host_base_path,
             host_dir_name=hostdir,
             exec_path=test.cdist_exec_path,
@@ -445,6 +478,7 @@ class StdinTestCase(test.CdistTestCase):
 
         self.local = local.Local(
             target_host=self.target_host,
+            target_host_tags=self.target_host_tags,
             base_root_path=host_base_path,
             host_dir_name=hostdir,
             exec_path=test.cdist_exec_path,
@@ -511,6 +545,7 @@ class EmulatorAlreadyExistingRequirementsWarnTestCase(test.CdistTestCase):
 
         self.local = local.Local(
             target_host=self.target_host,
+            target_host_tags=self.target_host_tags,
             base_root_path=host_base_path,
             host_dir_name=hostdir,
             exec_path=test.cdist_exec_path,
