@@ -26,8 +26,12 @@ import getpass
 import shutil
 import string
 import random
+import time
+import datetime
+import argparse
 
 import cdist
+import cdist.configuration as cc
 from cdist import test
 from cdist.exec import local
 
@@ -57,6 +61,7 @@ class LocalTestCase(test.CdistTestCase):
 
         self.local = local.Local(
             target_host=target_host,
+            target_host_tags=None,
             base_root_path=self.host_base_path,
             host_dir_name=self.hostdir,
             exec_path=test.cdist_exec_path
@@ -120,6 +125,7 @@ class LocalTestCase(test.CdistTestCase):
                 'localhost',
                 'localhost',
             ),
+            target_host_tags=None,
             base_root_path=self.host_base_path,
             host_dir_name=self.hostdir,
             exec_path=test.cdist_exec_path,
@@ -143,6 +149,7 @@ class LocalTestCase(test.CdistTestCase):
                 'localhost',
                 'localhost',
             ),
+            target_host_tags=None,
             base_root_path=self.host_base_path,
             host_dir_name=self.hostdir,
             exec_path=test.cdist_exec_path,
@@ -163,15 +170,20 @@ class LocalTestCase(test.CdistTestCase):
 
         os.environ['CDIST_PATH'] = conf_dir
 
+        configuration = cc.Configuration(argparse.Namespace(),
+                                         env=os.environ)
+
         link_test_local = local.Local(
             target_host=(
                 'localhost',
                 'localhost',
                 'localhost',
             ),
+            target_host_tags=None,
             base_root_path=self.host_base_path,
             host_dir_name=self.hostdir,
             exec_path=test.cdist_exec_path,
+            configuration=configuration.get_config(section='GLOBAL')
         )
 
         link_test_local._create_conf_path_and_link_conf_dirs()
@@ -183,24 +195,29 @@ class LocalTestCase(test.CdistTestCase):
     # other tests
 
     def test_run_success(self):
+        self.local.create_files_dirs()
         self.local.run([bin_true])
 
     def test_run_fail(self):
+        self.local.create_files_dirs()
         self.assertRaises(cdist.Error, self.local.run, [bin_false])
 
     def test_run_script_success(self):
+        self.local.create_files_dirs()
         handle, script = self.mkstemp(dir=self.temp_dir)
         with os.fdopen(handle, "w") as fd:
             fd.writelines(["#!/bin/sh\n", bin_true])
         self.local.run_script(script)
 
     def test_run_script_fail(self):
+        self.local.create_files_dirs()
         handle, script = self.mkstemp(dir=self.temp_dir)
         with os.fdopen(handle, "w") as fd:
             fd.writelines(["#!/bin/sh\n", bin_false])
         self.assertRaises(cdist.Error, self.local.run_script, script)
 
     def test_run_script_get_output(self):
+        self.local.create_files_dirs()
         handle, script = self.mkstemp(dir=self.temp_dir)
         with os.fdopen(handle, "w") as fd:
             fd.writelines(["#!/bin/sh\n", "echo foobar"])
@@ -224,6 +241,41 @@ class LocalTestCase(test.CdistTestCase):
         self.assertTrue(os.path.isdir(self.local.bin_path))
         self.assertTrue(os.path.isdir(self.local.conf_path))
 
+    def test_cache_subpath(self):
+        start_time = time.time()
+        dt = datetime.datetime.fromtimestamp(start_time)
+        pid = str(os.getpid())
+        cases = [
+            ['', self.local.hostdir, ],
+            ['/', self.local.hostdir, ],
+            ['//', self.local.hostdir, ],
+            ['/%%h', '%h', ],
+            ['%%h', '%h', ],
+            ['%P', pid, ],
+            ['x%P', 'x' + pid, ],
+            ['%h', self.hostdir, ],
+            ['%h/%Y-%m-%d/%H%M%S%f%P',
+             dt.strftime(self.hostdir + '/%Y-%m-%d/%H%M%S%f') + pid, ],
+            ['/%h/%Y-%m-%d/%H%M%S%f%P',
+             dt.strftime(self.hostdir + '/%Y-%m-%d/%H%M%S%f') + pid, ],
+            ['%Y-%m-%d/%H%M%S%f%P/%h',
+             dt.strftime('%Y-%m-%d/%H%M%S%f' + pid + os.sep + self.hostdir), ],
+            ['///%Y-%m-%d/%H%M%S%f%P/%h',
+             dt.strftime('%Y-%m-%d/%H%M%S%f' + pid + os.sep + self.hostdir), ],
+            ['%h/%Y-%m-%d/%H%M%S-%P',
+             dt.strftime(self.hostdir + '/%Y-%m-%d/%H%M%S-') + pid, ],
+            ['%Y-%m-%d/%H%M%S-%P/%h',
+             dt.strftime('%Y-%m-%d/%H%M%S-') + pid + os.sep + self.hostdir, ],
+            ['%N', self.local.target_host[0], ],
+        ]
+        for x in cases:
+            x.append(self.local._cache_subpath(start_time, x[0]))
+        # for fmt, expected, actual in cases:
+        #     print('\'{}\' \'{}\' \'{}\''.format(fmt, expected, actual))
+        for fmt, expected, actual in cases:
+            self.assertEqual(expected, actual)
+
+
 if __name__ == "__main__":
     import unittest
 
